==> types_boto3_connectcases-1.35.71-py3-none-any.whl: types_boto3_connectcases/paginator.py <==
"""
Type annotations for connectcases service client paginators.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_connectcases/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_connectcases.client import ConnectCasesClient
    from types_boto3_connectcases.paginator import (
        SearchCasesPaginator,
        SearchRelatedItemsPaginator,
    )

    session = Session()
    client: ConnectCasesClient = session.client("connectcases")

    search_cases_paginator: SearchCasesPaginator = client.get_paginator("search_cases")
    search_related_items_paginator: SearchRelatedItemsPaginator = client.get_paginator("search_related_items")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys
from typing import Generic, Iterator, TypeVar

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    SearchCasesRequestSearchCasesPaginateTypeDef,
    SearchCasesResponseTypeDef,
    SearchRelatedItemsRequestSearchRelatedItemsPaginateTypeDef,
    SearchRelatedItemsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("SearchCasesPaginator", "SearchRelatedItemsPaginator")


_ItemTypeDef = TypeVar("_ItemTypeDef")


class _PageIterator(PageIterator, Generic[_ItemTypeDef]):
    def __iter__(self) -> Iterator[_ItemTypeDef]:
        """
        Proxy method to specify iterator item type.
        """


class SearchCasesPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcases/paginator/SearchCases.html#ConnectCases.Paginator.SearchCases)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_connectcases/paginators/#searchcasespaginator)
    """

    def paginate(
        self, **kwargs: Unpack[SearchCasesRequestSearchCasesPaginateTypeDef]
    ) -> _PageIterator[SearchCasesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcases/paginator/SearchCases.html#ConnectCases.Paginator.SearchCases.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_connectcases/paginators/#searchcasespaginator)
        """


class SearchRelatedItemsPaginator(Paginator):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcases/paginator/SearchRelatedItems.html#ConnectCases.Paginator.SearchRelatedItems)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_connectcases/paginators/#searchrelateditemspaginator)
    """

    def paginate(
        self, **kwargs: Unpack[SearchRelatedItemsRequestSearchRelatedItemsPaginateTypeDef]
    ) -> _PageIterator[SearchRelatedItemsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcases/paginator/SearchRelatedItems.html#ConnectCases.Paginator.SearchRelatedItems.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_connectcases/paginators/#searchrelateditemspaginator)
        """

==> types_boto3_connectcases-1.36.0-py3-none-any.whl: types_boto3_connectcases/paginator.py <==
"""
Type annotations for connectcases service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_connectcases/paginators/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_connectcases.client import ConnectCasesClient
    from types_boto3_connectcases.paginator import (
        SearchCasesPaginator,
        SearchRelatedItemsPaginator,
    )

    session = Session()
    client: ConnectCasesClient = session.client("connectcases")

    search_cases_paginator: SearchCasesPaginator = client.get_paginator("search_cases")
    search_related_items_paginator: SearchRelatedItemsPaginator = client.get_paginator("search_related_items")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    SearchCasesRequestPaginateTypeDef,
    SearchCasesResponseTypeDef,
    SearchRelatedItemsRequestPaginateTypeDef,
    SearchRelatedItemsResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("SearchCasesPaginator", "SearchRelatedItemsPaginator")


if TYPE_CHECKING:
    _SearchCasesPaginatorBase = Paginator[SearchCasesResponseTypeDef]
else:
    _SearchCasesPaginatorBase = Paginator  # type: ignore[assignment]


class SearchCasesPaginator(_SearchCasesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcases/paginator/SearchCases.html#ConnectCases.Paginator.SearchCases)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_connectcases/paginators/#searchcasespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[SearchCasesRequestPaginateTypeDef]
    ) -> PageIterator[SearchCasesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcases/paginator/SearchCases.html#ConnectCases.Paginator.SearchCases.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_connectcases/paginators/#searchcasespaginator)
        """


if TYPE_CHECKING:
    _SearchRelatedItemsPaginatorBase = Paginator[SearchRelatedItemsResponseTypeDef]
else:
    _SearchRelatedItemsPaginatorBase = Paginator  # type: ignore[assignment]


class SearchRelatedItemsPaginator(_SearchRelatedItemsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcases/paginator/SearchRelatedItems.html#ConnectCases.Paginator.SearchRelatedItems)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_connectcases/paginators/#searchrelateditemspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[SearchRelatedItemsRequestPaginateTypeDef]
    ) -> PageIterator[SearchRelatedItemsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectcases/paginator/SearchRelatedItems.html#ConnectCases.Paginator.SearchRelatedItems.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_connectcases/paginators/#searchrelateditemspaginator)
        """
